# `b3`

Aspartik `b3` is an inference engine for Bayesian phylogenetic analysis.
It's inspired by BEAST2, but was developed from scratch with a focus on
conservative memory usage and portability.  It comes as a part of the
Aspartik suite, which can be installed with `pip`, and uses either
threads or CUDA to run fast parallel model inference.
